diff mbox

KVM test: Change the way subtests are loaded

Message ID 1256940465-5650-1-git-send-email-lmr@redhat.com (mailing list archive)
State New, archived
Headers show

Commit Message

Lucas Meneghel Rodrigues Oct. 30, 2009, 10:07 p.m. UTC
None
diff mbox

Patch

diff --git a/client/tests/kvm/kvm.py b/client/tests/kvm/kvm.py
index 204164d..06ef9f5 100644
--- a/client/tests/kvm/kvm.py
+++ b/client/tests/kvm/kvm.py
@@ -22,9 +22,9 @@  class kvm(test.test):
     """
     version = 1
     def initialize(self):
-        # Make it possible to import modules from the test's bindir
-        sys.path.append(self.bindir)
+        # Make it possible to import modules from the subtest dir
         self.subtest_dir = os.path.join(self.bindir, 'tests')
+        sys.path.append(self.subtest_dir)
 
 
     def run_once(self, params):
@@ -51,7 +51,7 @@  class kvm(test.test):
                     raise error.TestError("No %s.py test file found" % type)
                 # Load the tests directory (which was turned into a py module)
                 try:
-                    test_module = __import__("tests.%s" % type)
+                    test_module = __import__(type)
                 except ImportError, e:
                     raise error.TestError("Failed to import test %s: %s" %
                                           (type, e))
@@ -60,7 +60,8 @@  class kvm(test.test):
                 kvm_preprocessing.preprocess(self, params, env)
                 kvm_utils.dump_env(env, env_filename)
                 # Run the test function
-                eval("test_module.%s.run_%s(self, params, env)" % (type, type))
+                run_func = getattr(test_module, "run_%s" % type)
+                run_func(self, params, env)
                 kvm_utils.dump_env(env, env_filename)
 
             except Exception, e: